##
##  tar.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         tar
Summary:      Management of TAR Archive Format Files
URL:          http://www.gnu.org/software/tar/
Vendor:       Free Software Foundation
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Archiver
License:      GPL
Version:      1.35
Release:      20230720

#   list of sources
Source0:      http://ftp.gnu.org/gnu/tar/tar-%{version}.tar.gz
Source1:      tar.1
Patch0:       tar.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Tar is short for "tape archiver", so named for historical reasons;
    the tar program creates, adds files to, or extracts files from an
    archive file in tar format, called a tarfile. A tarfile is often
    a magnetic tape, but can be a floppy diskette or any regular disk
    file.

%track
    prog tar = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/tar/
        regex     = tar-(\d+\.\d+(\.\d+)?)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    ( echo 'am_cv_func_iconv=no'
      echo 'am_cv_lib_iconv=no'
      echo 'ac_cv_lib_iconv_iconv=no'
      echo 'ac_cv_header_iconv_h=no'
      echo 'ac_cv_type_iconv_t=no'
    ) >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    GREP="grep" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --infodir=%{l_prefix}/info \
        --disable-nls
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR="$RPM_BUILD_ROOT"
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -m 644 \
        %{SOURCE tar.1} $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/libexec
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

